@@ -1,5 +1,5 @@
 SetImputationTimes <-
 function(dataset, t.values) {
-  if(is.null(t.values)) t.values <- unique(dataset[, 2])
+  if(is.null(t.values)) t.values <- sort(unique(dataset[, 2]))
   return(t.values)
 }
